Testing tools
-------------

The nose.tools module provides a number of testing aids that you may
find useful, including decorators for restricting test execution time
and testing for exceptions, and all of the same assertX methods found
in `unittest.TestCase` (only spelled in :pep:`8#function-names`
fashion, so `assert_equal` rather than `assertEqual`).

.. automodule :: nose.tools
   :members:
